# -*- coding: utf-8 -*-
#
# Copyright 2017 Ricequant, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import pickle

from ..model.instrument import Instrument


class InstrumentStore(object):
    def __init__(self, f):
        with open(f, 'rb') as store:
            d = pickle.load(store)
        self._instruments = [Instrument(i) for i in d]

    def get_all_instruments(self):
        return self._instruments
