#!/usr/bin/env python
# encoding: utf-8


"""
@author: Gu Xi
@contact: guxi@ricequant.com
@site: http://www.ricequant.com
@file: __init__.py.py
@time: 2017/2/17 下午1:35
"""


def func():
    pass


if __name__ == '__main__':
    pass